@@ -29,11 +29,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.23
+Version v3.0.24
 
 =cut
 
-our $VERSION = version->declare("v3.0.23");
+our $VERSION = version->declare("v3.0.24");
 
 =head1 SYNOPSIS
 
@@ -175,24 +175,26 @@ sub find
 {
 	my ( $self, @paths ) = @_;
 
-	my $rule    = Path::Iterator::Rule->new;
-	my %options = (
+	my $check_re  = $self->check_regex;
+	my $ignore_re = $self->ignore_regex;
+	my $rule      = Path::Iterator::Rule->new;
+	my %options   = (
 		follow_symlinks => 0,
 	);
 
 	$rule->max_depth(1)
 		unless $self->recursive;
-	$rule->not_name( $self->ignore_regex );
+	$rule->not( sub {/$ignore_re/} );
 	$rule->file->nonempty;
 
 	if ( @paths >> 1 ) {
 		if ( $self->skipped ) {
-			my $skipped = $rule->clone->not_name( $self->check_regex );
+			my $skipped = $rule->clone->not( sub {/$check_re/} );
 			for ( $skipped->all( @paths, \%options ) ) {
 				warn "skipped file $_\n";
 			}
 		}
-		$rule->name( $self->check_regex );
+		$rule->and( sub {/$check_re/} );
 	}
 
 	return $rule->all( @paths, \%options );
